cairocffi
=========

cairocffi is a `CFFI`_-based drop-in replacement for Pycairo_,
a set of Python bindings and object-oriented API for cairo_.
Cairo is a 2D vector graphics library with support for multiple backends
including image buffers, PNG, PostScript, PDF, and SVG file output.

Additionally, the :mod:`cairocffi.pixbuf` module uses GDK-PixBuf_
to decode various image formats for use in cairo.

.. _CFFI: https://cffi.readthedocs.org/
.. _Pycairo: http://cairographics.org/pycairo/
.. _cairo: http://cairographics.org/
.. _GDK-PixBuf: https://live.gnome.org/GdkPixbuf

* `Latest documentation <http://packages.python.org/cairocffi/>`_
* `Source code and issue tracker <https://github.com/SimonSapin/cairocffi>`_
  on GitHub.
* Install with ``pip install cairocffi``
* Python 2.6, 2.7 and 3.x. Tested with CPython and Pypy.
* API compatible with Pycairo.
* Works with any version of cairo.
